<template>
  <Dialog v-model="dialogVisible" :title="dialogTitle" width="50%">
    <el-form
      ref="formRef"
      v-loading="formLoading"
      :model="formData"
      :rules="formRules"
      label-width="130px"
    >
      <el-row>
        <el-col :span="12">
          <el-form-item label="配置名称" prop="configName">
            <el-input v-model="formData.configName" placeholder="请输入配置名称"/>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="配置编码" prop="configCode">
            <el-input v-model="formData.configCode" placeholder="请输入配置编码"/>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="预测项" prop="outputId">
            <el-select-v2
              v-model="formData.outputId"
              :options="normalItemList || []"
              placeholder="请选择"
              :props="{value:'value',label:'label',options:'children'}"
              clearable
              filterable
              :fit-input-width="false"
            />
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="测点" prop="pointId">
            <el-select
              v-model="formData.pointId"
              filterable
              clearable
              placeholder="请选择">
              <el-option
                v-for="item in pointList"
                :key="item.id"
                :label="item.pointName"
                :value="item.id"/>
            </el-select>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="取值时间范围" prop="t">
            <el-input-number v-model="formData.t" :min="1" clearable/>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="调整方向" prop="adjustDirection">
            <el-select v-model="formData.adjustDirection" placeholder="请选择调整方向">
              <el-option
                v-for="dict in getIntDictOptions(DICT_TYPE.ADJUST_DIRECTION)"
                :key="dict.value"
                :label="dict.label"
                :value="dict.value"
              />
            </el-select>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="触发规则" prop="triggerRule">
            <el-select v-model="formData.triggerRule" placeholder="请选择触发规则">
              <el-option
                v-for="dict in getStrDictOptions(DICT_TYPE.ADJUST_TRIGGER_RULE)"
                :key="dict.value"
                :label="dict.label"
                :value="dict.value"
              />
            </el-select>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="触发值" prop="triggerValue">
            <el-input-number v-model="formData.triggerValue"/>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="调整值计算规则" prop="adjustValueRule">
            <el-select v-model="formData.adjustValueRule" placeholder="请选择调整值计算规则">
              <el-option
                v-for="dict in getStrDictOptions(DICT_TYPE.ADJUST_VALUE_RULE)"
                :key="dict.value"
                :label="dict.label"
                :value="dict.value"
              />
            </el-select>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="调整长度" prop="adjustLength">
            <el-input-number v-model="formData.adjustLength"/>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="是否启用" prop="isEnable">
            <el-select v-model="formData.isEnable" placeholder="请选择">
              <el-option
                v-for="dict in getIntDictOptions(DICT_TYPE.COM_IS_INT)"
                :key="dict.value"
                :label="dict.label"
                :value="dict.value"
              />
            </el-select>
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>
    <template #footer>
      <el-button :disabled="formLoading" type="primary" @click="submitForm">确 定</el-button>
      <el-button @click="dialogVisible = false">取 消</el-button>
    </template>
  </Dialog>
</template>
<script lang="ts" setup>
import {DICT_TYPE, getIntDictOptions,getStrDictOptions} from "@/utils/dict";
import * as MmPredictItem from '@/api/model/pre/item'
import {CommonEnabled} from "@/utils/constants";
import * as AutoAdjustConfigApi from '@/api/model/pre/autoAdjust/config'
import * as DaPoint from "@/api/data/da/point";

defineOptions({name: 'MmPredictAutoAdjustConfigForm'})

const {t} = useI18n() // 国际化
const message = useMessage() // 消息弹窗
const dialogVisible = ref(false) // 弹窗的是否展示
const dialogTitle = ref('') // 弹窗的标题
const formLoading = ref(false) // 表单的加载中：1）修改时的数据加载；2）提交的按钮禁用
const formType = ref('') // 表单的类型：create - 新增；update - 修改
const formData = ref({
  id: undefined,
  configName: undefined,
  configCode: undefined,
  outputId: undefined,
  pointId: undefined,
  t: undefined,
  triggerRule: undefined,
  triggerValue: undefined,
  adjustDirection: undefined,
  adjustValueRule: undefined,
  adjustLength: 1,
  isEnable: 1,
})
const formRules = reactive({
  configName: [{required: true, message: '配置名称不能为空', trigger: 'blur'}],
  configCode: [{required: true, message: '配置编码不能为空', trigger: 'blur'}],
  outputId: [{required: true, message: '预测输出不能为空', trigger: 'blur'}],
  pointId: [{required: true, message: '测点不能为空', trigger: 'blur'}],
  t: [{required: true, message: '取值时间范围不能为空', trigger: 'blur'}],
  triggerRule: [{required: true, message: '触发规则不能为空', trigger: 'blur'}],
  triggerValue: [{required: true, message: '触发值不能为空', trigger: 'blur'}],
  adjustDirection: [{required: true, message: '调整方向不能为空', trigger: 'blur'}],
  adjustValueRule: [{required: true, message: '调整值计算规则不能为空', trigger: 'blur'}],
  adjustLength: [{required: true, message: '调整长度不能为空', trigger: 'blur'}],
  isEnable: [{required: true, message: '是否启用不能为空', trigger: 'blur'}],
})
const formRef = ref() // 表单 Ref

const normalItemList = ref([])
const pointList = ref([])

/** 打开弹窗 */
const open = async (type: string, id?: number) => {
  dialogVisible.value = true
  dialogTitle.value = t('action.' + type)
  formType.value = type
  resetForm()

  normalItemList.value = await MmPredictItem.getNormalItemList()
  // 获取数据点列表
  pointList.value = await DaPoint.getPointSimpleList({})

  // 修改时，设置数据
  if (id) {
    formLoading.value = true
    try {
      formData.value = await AutoAdjustConfigApi.getInfo(id)
    } finally {
      formLoading.value = false
    }
  }

}
defineExpose({open}) // 提供 open 方法，用于打开弹窗

/** 提交表单 */
const emit = defineEmits(['success']) // 定义 success 事件，用于操作成功后的回调
const submitForm = async () => {
  // 校验表单
  if (!formRef) return
  const valid = await formRef.value.validate()
  if (!valid) return
  // 提交请求
  formLoading.value = true
  try {
    const data = formData.value
    if (formType.value === 'create') {
      await AutoAdjustConfigApi.create(data)
      message.success(t('common.createSuccess'))
    } else {
      await AutoAdjustConfigApi.update(data)
      message.success(t('common.updateSuccess'))
    }
    dialogVisible.value = false
    // 发送操作成功的事件
    emit('success')
  } finally {
    formLoading.value = false
  }
}

/** 重置表单 */
const resetForm = () => {
  formData.value = {
    id: undefined,
    configName: undefined,
    configCode: undefined,
    outputId: undefined,
    pointId: undefined,
    t: undefined,
    triggerRule: undefined,
    triggerValue: undefined,
    adjustDirection: undefined,
    adjustLength: 1,
    adjustValueRule: undefined,
    isEnable: 1,
  }
  formRef.value?.resetFields()
}
</script>
